==> phpBB-3.3.12-deutsch_to_3.3.14-deutsch.tar.bz2: install/update/index.php <==
<?php

if (!defined('IN_PHPBB'))
{
	exit;
}

// Set update info with file structure to update
$update_info = array(
	'version'	=> array('from' => '3.3.12', 'to' => '3.3.14'),
	'files'		=> array(
		'adm/style/acp_ext_list.html',
		'adm/style/acp_groups.html',
		'adm/style/acp_main.html',
		'composer.lock',
		'config/default/container/services_console.yml',
		'config/default/container/services_ucp.yml',
		'config/default/routing/ucp.yml',
		'includes/acp/acp_bbcodes.php',
		'includes/acp/acp_extensions.php',
		'includes/acp/acp_groups.php',
		'includes/acp/acp_logs.php',
		'includes/acp/acp_main.php',
		'includes/acp/acp_users.php',
		'includes/constants.php',
		'includes/functions.php',
		'includes/functions_content.php',
		'includes/functions_display.php',
		'includes/functions_messenger.php',
		'includes/functions_module.php',
		'includes/functions_privmsgs.php',
		'includes/mcp/mcp_post.php',
		'includes/mcp/mcp_queue.php',
		'includes/mcp/mcp_reports.php',
		'includes/ucp/ucp_prefs.php',
		'includes/utf/utf_tools.php',
		'language/de/README.md',
		'language/de/acp/extensions.php',
		'language/de/acp/posting.php',
		'language/de/cli.php',
		'language/de/common.php',
		'language/de/help/faq.php',
		'language/de/viewtopic.php',
		'language/de_x_sie/README.md',
		'language/de_x_sie/acp/extensions.php',
		'language/de_x_sie/acp/posting.php',
		'language/de_x_sie/cli.php',
		'language/de_x_sie/common.php',
		'language/de_x_sie/help/faq.php',
		'language/de_x_sie/viewtopic.php',
		'language/en/acp/extensions.php',
		'language/en/acp/posting.php',
		'language/en/cli.php',
		'language/en/help/faq.php',
		'language/en/viewtopic.php',
		'memberlist.php',
		'phpbb/.htaccess',
		'phpbb/auth/auth.php',
		'phpbb/avatar/driver/gravatar.php',
		'phpbb/cache/driver/file.php',
		'phpbb/cache/driver/redis.php',
		'phpbb/captcha/plugins/recaptcha_v3.php',
		'phpbb/console/command/fixup/update_hashes.php',
		'phpbb/console/command/reparser/reparse.php',
		'phpbb/console/command/user/add.php',
		'phpbb/console/command/user/delete_id.php',
		'phpbb/cron/task/core/update_hashes.php',
		'phpbb/db/driver/mysqli.php',
		'phpbb/db/migration/data/v33x/v3313.php',
		'phpbb/db/migration/data/v33x/v3313rc1.php',
		'phpbb/db/migration/data/v33x/v3314.php',
		'phpbb/db/migration/data/v33x/v3314rc1.php',
		'phpbb/db/migration/tool/permission.php',
		'phpbb/extension/manager.php',
		'phpbb/file_downloader.php',
		'phpbb/install/module/install_finish/task/install_extensions.php',
		'phpbb/install/module/update_database/task/update_extensions.php',
		'phpbb/path_helper.php',
		'phpbb/search/fulltext_native.php',
		'phpbb/session.php',
		'phpbb/textreparser/base.php',
		'phpbb/textreparser/reparser_interface.php',
		'phpbb/ucp/controller/delete_cookies.php',
		'posting.php',
		'search.php',
		'styles/prosilver/style.cfg',
		'styles/prosilver/template/ajax.js',
		'styles/prosilver/template/bbcode.html',
		'styles/prosilver/template/forum_fn.js',
		'styles/prosilver/template/mcp_post.html',
		'styles/prosilver/template/memberlist_view.html',
		'styles/prosilver/template/posting_editor.html',
		'styles/prosilver/template/posting_pm_header.html',
		'styles/prosilver/template/ucp_groups_manage.html',
		'styles/prosilver/template/ucp_pm_viewmessage.html',
		'styles/prosilver/template/ucp_prefs_post.html',
		'styles/prosilver/theme/common.css',
		'styles/prosilver/theme/responsive.css',
		'styles/prosilver/theme/stylesheet.css',
		'ucp.php',
		'viewforum.php',
		'viewtopic.php',
		'web.config',
	),
	'binary'		=> array(),
	'deleted'		=> array(),
);

==> phpBB-3.3.13-deutsch_to_3.3.15-deutsch.tar.bz2: install/update/index.php <==
<?php

if (!defined('IN_PHPBB'))
{
	exit;
}

// Set update info with file structure to update
$update_info = array(
	'version'	=> array('from' => '3.3.13', 'to' => '3.3.15'),
	'files'		=> array(
		'adm/style/acp_ext_list.html',
		'adm/style/admin.js',
		'adm/style/ajax.js',
		'includes/acp/acp_board.php',
		'includes/acp/acp_extensions.php',
		'includes/acp/acp_groups.php',
		'includes/acp/acp_main.php',
		'includes/constants.php',
		'includes/functions.php',
		'includes/functions_content.php',
		'includes/functions_messenger.php',
		'includes/functions_module.php',
		'includes/functions_user.php',
		'includes/mcp/mcp_queue.php',
		'language/de/README.md',
		'language/de/acp/board.php',
		'language/de/acp/extensions.php',
		'language/de/cli.php',
		'language/de/common.php',
		'language/de/help/faq.php',
		'language/de/viewtopic.php',
		'language/de_x_sie/README.md',
		'language/de_x_sie/acp/board.php',
		'language/de_x_sie/acp/extensions.php',
		'language/de_x_sie/cli.php',
		'language/de_x_sie/common.php',
		'language/de_x_sie/help/faq.php',
		'language/de_x_sie/viewtopic.php',
		'language/en/acp/board.php',
		'language/en/acp/extensions.php',
		'language/en/cli.php',
		'language/en/common.php',
		'language/en/help/faq.php',
		'language/en/viewtopic.php',
		'memberlist.php',
		'phpbb/auth/auth.php',
		'phpbb/console/command/reparser/reparse.php',
		'phpbb/db/driver/mysqli.php',
		'phpbb/db/migration/data/v33x/topic_views_update.php',
		'phpbb/db/migration/data/v33x/v3314.php',
		'phpbb/db/migration/data/v33x/v3314rc1.php',
		'phpbb/db/migration/data/v33x/v3315.php',
		'phpbb/db/migration/data/v33x/v3315rc1.php',
		'phpbb/feed/controller/feed.php',
		'phpbb/file_downloader.php',
		'phpbb/path_helper.php',
		'phpbb/search/base.php',
		'phpbb/textreparser/base.php',
		'phpbb/textreparser/reparser_interface.php',
		'phpbb/ucp/controller/reset_password.php',
		'phpbb/version_helper.php',
		'search.php',
		'styles/prosilver/style.cfg',
		'styles/prosilver/template/bbcode.html',
		'styles/prosilver/template/forum_fn.js',
		'styles/prosilver/template/forumlist_body.html',
		'styles/prosilver/template/search_results.html',
		'styles/prosilver/template/ucp_pm_viewmessage.html',
		'viewforum.php',
	),
	'binary'		=> array(),
	'deleted'		=> array(),
);
